# crYOLO Boxmanager

The crYOLO boxmanger was written to produce annotation data for [crYOLO](http://sphire.mpg.de/wiki/doku.php?id=downloads:cryolo_1), as deep learning based particle picking procedure for cryo electro microscopy.

